@@ -5,7 +5,7 @@ package WWW::Slides::Talk;
    #   use diagnostics;
    use strict;
    use Carp;
-   use version; our $VERSION = qv('0.0.1');
+   use version; our $VERSION = qv('0.0.3');
    use Object::InsideOut;
    use IO::Socket;
    use IO::Select;
@@ -257,6 +257,7 @@ package WWW::Slides::Talk;
          handle        => $handle,
          slide_show    => scalar $self->get_slide_show(),
          current_slide => scalar $self->tracker->current(),
+         check_booking => $self->must_book(),
       );
 
       # Register attendee
@@ -373,23 +374,23 @@ __END__
 
 =head1 NAME
 
-WWW::Slides - [Una riga di descrizione dello scopo del modulo]
+WWW::Slides::Talk - class to represent a Talk in the WWW::Slides system
 
 
 =head1 VERSION
 
-This document describes WWW::Slides version 0.0.1
+This document describes WWW::Slides::Talk version 0.0.3
 
 
 =head1 SYNOPSIS
 
-    use WWW::Slides;
+   use WWW::Slides::Talk;
 
-=for l'autore, da riempire:
-   Qualche breve esempio con codice che mostri l'utilizzo pi comune.
-   Questa sezione sar quella probabilmente pi letta, perch molti
-   utenti si annoiano a leggere tutta la documentazione, per cui
-    meglio essere il pi educativi ed esplicativi possibile.
+   my $talk = WWW::Slides::Talk->new(
+      controller => $controller, # e.g. WWW::Slides::Controller::TCP
+      port       => 50505,       # where am I acting as HTTP server
+      slide_show => $slide_show, # e.g. WWW::Slides::SlideShow
+   );
   
   
 =head1 DESCRIPTION
@@ -445,7 +446,7 @@ This document describes WWW::Slides version 0.0.1
    devono anche includere dettagli su eventuali linguaggi di configurazione
    utilizzati.
   
-WWW::Slides requires no configuration files or environment variables.
+WWW::Slides::Talk requires no configuration files or environment variables.
 
 
 =head1 DEPENDENCIES
